@@ -16,7 +16,15 @@ limitations under the License.
 
 from typing import Optional
 
-from langtrace_python_sdk.types import DisableInstrumentations, InstrumentationType
+from langtrace_python_sdk.constants.exporter.langtrace_exporter import (
+    LANGTRACE_REMOTE_URL,
+)
+from langtrace_python_sdk.types import (
+    DisableInstrumentations,
+    InstrumentationType,
+    InstrumentationMethods,
+)
+from langtrace_python_sdk.utils.langtrace_sampler import LangtraceSampler
 from opentelemetry import trace
 from opentelemetry.sdk.trace import TracerProvider
 from opentelemetry.sdk.trace.export import (
@@ -32,6 +40,7 @@ from langtrace_python_sdk.instrumentation import (
     AnthropicInstrumentation,
     ChromaInstrumentation,
     CohereInstrumentation,
+    CrewAIInstrumentation,
     GroqInstrumentation,
     LangchainInstrumentation,
     LangchainCommunityInstrumentation,
@@ -42,10 +51,13 @@ from langtrace_python_sdk.instrumentation import (
     PineconeInstrumentation,
     QdrantInstrumentation,
     WeaviateInstrumentation,
+    OllamaInstrumentor,
+    DspyInstrumentation,
 )
 from opentelemetry.instrumentation.sqlalchemy import SQLAlchemyInstrumentor
 from colorama import Fore
 from langtrace_python_sdk.utils import check_if_sdk_is_outdated
+import os
 
 
 def init(
@@ -53,15 +65,24 @@ def init(
     batch: bool = True,
     write_spans_to_console: bool = False,
     custom_remote_exporter=None,
-    api_host: Optional[str] = None,
+    api_host: Optional[str] = LANGTRACE_REMOTE_URL,
     disable_instrumentations: Optional[DisableInstrumentations] = None,
+    disable_tracing_for_functions: Optional[InstrumentationMethods] = None,
 ):
+
+    host = (
+        os.environ.get("LANGTRACE_API_HOST", None) or api_host or LANGTRACE_REMOTE_URL
+    )
     check_if_sdk_is_outdated()
     print(Fore.GREEN + "Initializing Langtrace SDK.." + Fore.RESET)
-    provider = TracerProvider(resource=Resource.create({"service.name": sys.argv[0]}))
+    sampler = LangtraceSampler(disabled_methods=disable_tracing_for_functions)
+    provider = TracerProvider(
+        resource=Resource.create({"service.name": sys.argv[0]}),
+        sampler=sampler,
+    )
 
     remote_write_exporter = (
-        LangTraceExporter(api_key=api_key, api_host=api_host)
+        LangTraceExporter(api_key=api_key, api_host=host)
         if custom_remote_exporter is None
         else custom_remote_exporter
     )
@@ -70,6 +91,7 @@ def init(
     simple_processor_remote = SimpleSpanProcessor(remote_write_exporter)
     simple_processor_console = SimpleSpanProcessor(console_exporter)
 
+    os.environ["LANGTRACE_API_HOST"] = host.replace("/api/trace", "")
     # Initialize tracer
     trace.set_tracer_provider(provider)
     all_instrumentations = {
@@ -87,6 +109,9 @@ def init(
         "cohere": CohereInstrumentation(),
         "weaviate": WeaviateInstrumentation(),
         "sqlalchemy": SQLAlchemyInstrumentor(),
+        "ollama": OllamaInstrumentor(),
+        "dspy": DspyInstrumentation(),
+        "crewai": CrewAIInstrumentation(),
     }
 
     init_instrumentations(disable_instrumentations, all_instrumentations)
@@ -101,8 +126,8 @@ def init(
         else:
             provider.add_span_processor(simple_processor_remote)
 
-    elif api_host is not None:
-        print(Fore.BLUE + f"Exporting spans to custom host: {api_host}.." + Fore.RESET)
+    elif host != LANGTRACE_REMOTE_URL:
+        print(Fore.BLUE + f"Exporting spans to custom host: {host}.." + Fore.RESET)
         if batch:
             provider.add_span_processor(batch_processor_remote)
         else:
